# References

## Orthography and phonology

- Agjenzie Regjonâl pe Lenghe Furlane (ARLeF). (2017). *La grafie uficiâl de lenghe furlane* (ed. 2017) [PDF](https://arlef.it/app/uploads/documenti/Grafie_cuadrileng%C3%A2l_ed2017.pdf) ([archive](https://web.archive.org/web/*/https://arlef.it/app/uploads/documenti/Grafie_cuadrileng%C3%A2l_ed2017.pdf)).
- ARLeF. (2020, December). *Dut par furlan – Lezione 7* [PDF](https://arlef.it/app/uploads/2020/12/dutparfurlan_lez-7-ita-def.pdf) ([archive](https://web.archive.org/web/*/https://arlef.it/app/uploads/2020/12/dutparfurlan_lez-7-ita-def.pdf)).
- Wikipedia contributors. (n.d.). *Friulian language*. In Wikipedia. Retrieved September 8, 2025, from [https://en.wikipedia.org/wiki/Friulian_language](https://en.wikipedia.org/wiki/Friulian_language) ([archive](https://web.archive.org/web/*/https://en.wikipedia.org/wiki/Friulian_language)).
- Omniglot. (n.d.). *Friulian language*. [https://www.omniglot.com/writing/friulian.htm](https://www.omniglot.com/writing/friulian.htm) ([archive](https://web.archive.org/web/*/https://www.omniglot.com/writing/friulian.htm)).
- Miotti, R. (2002). Friulian. *Journal of the International Phonetic Association, 32*(2), 249–254. [DOI](https://doi.org/10.1017/s0025100302001056) ([archive](https://web.archive.org/web/*/https://doi.org/10.1017/s0025100302001056)).
- Roseano, P., & Finco, S. (2021). Rhaeto-Romance: Friulian, Ladin, and Romansh. In A. Lazzaroni et al. (Eds.), *Manual of Romance Phonetics and Phonology*. De Gruyter. [De Gruyter](https://www.degruyterbrill.com/document/doi/10.1515/9783110550283-021/html) ([archive](https://web.archive.org/web/*/https://www.degruyterbrill.com/document/doi/10.1515/9783110550283-021/html)). [Alternate excerpt](https://www.researchgate.net/publication/354400742_Rhaeto-Romance_Friulian_Ladin_and_Romansh) ([archive](https://web.archive.org/web/*/https://www.researchgate.net/publication/354400742_Rhaeto-Romance_Friulian_Ladin_and_Romansh)).
- Iosad, P. (2012). Final devoicing and vowel lengthening in the north of Italy: A representational approach. *Lingua, 122*(8), 841–864. [DOI](https://doi.org/10.1016/j.lingua.2012.02.005) ([archive](https://web.archive.org/web/*/https://doi.org/10.1016/j.lingua.2012.02.005)).
- Baroni, M., & Vanelli, L. (2000). The relationship between vowel length and consonantal voicing in Friulian. In N. Burton-Roberts, P. Carr, & G. Docherty (Eds.), *Phonological Knowledge* (pp. 29–49). Benjamins. [DOI](https://doi.org/10.1075/cilt.212.04bar) ([archive](https://web.archive.org/web/*/https://doi.org/10.1075/cilt.212.04bar)).

## Gold lemma → IPA (Wiktionary)

- cûr — [Wiktionary](https://en.wiktionary.org/wiki/c%C3%BBr) ([archive](https://web.archive.org/web/*/https://en.wiktionary.org/wiki/c%C3%BBr)).
- fûc — [Wiktionary](https://en.wiktionary.org/wiki/f%C3%BBc) ([archive](https://web.archive.org/web/*/https://en.wiktionary.org/wiki/f%C3%BBc)).
- pôc — [Wiktionary](https://en.wiktionary.org/wiki/p%C3%B4c) ([archive](https://web.archive.org/web/*/https://en.wiktionary.org/wiki/p%C3%B4c)).
- sêt — [Wiktionary](https://en.wiktionary.org/wiki/s%C3%AAt) ([archive](https://web.archive.org/web/*/https://en.wiktionary.org/wiki/s%C3%AAt)).
- fâ — [Wiktionary](https://en.wiktionary.org/wiki/f%C3%A2) ([archive](https://web.archive.org/web/*/https://en.wiktionary.org/wiki/f%C3%A2)).
- fîl — [Wiktionary](https://en.wiktionary.org/wiki/f%C3%AEl) ([archive](https://web.archive.org/web/*/https://en.wiktionary.org/wiki/f%C3%AEl)).
- patî — [Wiktionary](https://en.wiktionary.org/wiki/pat%C3%AE) ([archive](https://web.archive.org/web/*/https://en.wiktionary.org/wiki/pat%C3%AE)).
- sufrî — [Wiktionary](https://en.wiktionary.org/wiki/sufr%C3%AE) ([archive](https://web.archive.org/web/*/https://en.wiktionary.org/wiki/sufr%C3%AE)).
- nemâl — [Wiktionary](https://en.wiktionary.org/wiki/nem%C3%A2l) ([archive](https://web.archive.org/web/*/https://en.wiktionary.org/wiki/nem%C3%A2l)).
- ìsule — [Wiktionary](https://en.wiktionary.org/wiki/%C3%ACsule) ([archive](https://web.archive.org/web/*/https://en.wiktionary.org/wiki/%C3%ACsule)).
- orele — [Wiktionary](https://en.wiktionary.org/wiki/orele) ([archive](https://web.archive.org/web/*/https://en.wiktionary.org/wiki/orele)).
- strie — [Wiktionary](https://en.wiktionary.org/wiki/strie) ([archive](https://web.archive.org/web/*/https://en.wiktionary.org/wiki/strie)).
- glace — [Wiktionary](https://en.wiktionary.org/wiki/glace) ([archive](https://web.archive.org/web/*/https://en.wiktionary.org/wiki/glace)).
- glaç — [Wiktionary](https://en.wiktionary.org/wiki/gla%C3%A7) ([archive](https://web.archive.org/web/*/https://en.wiktionary.org/wiki/gla%C3%A7)).
- cjaval — [Wiktionary](https://en.wiktionary.org/wiki/cjaval) ([archive](https://web.archive.org/web/*/https://en.wiktionary.org/wiki/cjaval)).
- pît — [Wiktionary](https://en.wiktionary.org/wiki/p%C3%AEt) ([archive](https://web.archive.org/web/*/https://en.wiktionary.org/wiki/p%C3%AEt)).
- mûr — [Wiktionary](https://en.wiktionary.org/wiki/m%C3%BBr) ([archive](https://web.archive.org/web/*/https://en.wiktionary.org/wiki/m%C3%BBr)).
- côr — [Wiktionary](https://en.wiktionary.org/wiki/c%C3%B4r) ([archive](https://web.archive.org/web/*/https://en.wiktionary.org/wiki/c%C3%B4r)).
- gjat — [Wiktionary](https://en.wiktionary.org/wiki/gjat) ([archive](https://web.archive.org/web/*/https://en.wiktionary.org/wiki/gjat)).
- zûc — [Wiktionary](https://en.wiktionary.org/wiki/z%C3%BBc) ([archive](https://web.archive.org/web/*/https://en.wiktionary.org/wiki/z%C3%BBc)).
- cjase — [Wiktionary](https://en.wiktionary.org/wiki/cjase) ([archive](https://web.archive.org/web/*/https://en.wiktionary.org/wiki/cjase)).
- cjandele — [Wiktionary](https://en.wiktionary.org/wiki/cjandele) ([archive](https://web.archive.org/web/*/https://en.wiktionary.org/wiki/cjandele)).

## Other

- Wiktionary. *Category: Friulian terms with IPA pronunciation*. [https://en.wiktionary.org/wiki/Category:Friulian_terms_with_IPA_pronunciation](https://en.wiktionary.org/wiki/Category:Friulian_terms_with_IPA_pronunciation) ([archive](https://web.archive.org/web/*/https://en.wiktionary.org/wiki/Category:Friulian_terms_with_IPA_pronunciation)).

## Numbers and abbreviations

- Wiktionary. *Category: Friulian cardinal numbers*. [https://en.wiktionary.org/wiki/Category:Friulian_cardinal_numbers](https://en.wiktionary.org/wiki/Category:Friulian_cardinal_numbers) ([archive](https://web.archive.org/web/*/https://en.wiktionary.org/wiki/Category:Friulian_cardinal_numbers)).

